@@ -5,6 +5,7 @@ import click
 
 from ..version import __version__
 from . import rootio, spec, infer, patchset, complete
+from ..contrib import cli as contrib
 
 logging.basicConfig()
 log = logging.getLogger(__name__)
@@ -29,8 +30,11 @@ pyhf.add_command(spec.digest)
 pyhf.add_command(spec.sort)
 
 # pyhf.add_command(infer.cli)
+pyhf.add_command(infer.fit)
 pyhf.add_command(infer.cls)
 
 pyhf.add_command(patchset.cli)
 
 pyhf.add_command(complete.cli)
+
+pyhf.add_command(contrib.cli)
