@@ -36,14 +36,14 @@ def wrap_objective(objective, data, pdf, stitch_pars, do_grad=False, jit_pieces=
     Wrap the objective function for the minimization.
 
     Args:
-        objective (`func`): objective function
-        data (`list`): observed data
+        objective (:obj:`func`): objective function
+        data (:obj:`list`): observed data
         pdf (~pyhf.pdf.Model): The statistical model adhering to the schema model.json
-        stitch_pars (`func`): callable that stitches parameters, see :func:`pyhf.optimize.common.shim`.
-        do_grad (`bool`): enable autodifferentiation mode. Default is off.
+        stitch_pars (:obj:`func`): callable that stitches parameters, see :func:`pyhf.optimize.common.shim`.
+        do_grad (:obj:`bool`): enable autodifferentiation mode. Default is off.
 
     Returns:
-        objective_and_grad (`func`): tensor backend wrapped objective,gradient pair
+        objective_and_grad (:obj:`func`): tensor backend wrapped objective,gradient pair
     """
     tensorlib, _ = get_backend()
     # NB: tuple arguments that need to be hashable (static_argnums)
