@@ -9,7 +9,7 @@ def _tensorviewer_from_parmap(par_map, batch_size):
     names, slices, _ = list(
         zip(
             *sorted(
-                [(k, v['slice'], v['slice'].start,) for k, v in par_map.items()],
+                [(k, v['slice'], v['slice'].start) for k, v in par_map.items()],
                 key=lambda x: x[2],
             )
         )
@@ -17,9 +17,7 @@ def _tensorviewer_from_parmap(par_map, batch_size):
     return _tensorviewer_from_slices(slices, names, batch_size)
 
 
-def extract_index_access(
-    baseviewer, subviewer, indices,
-):
+def extract_index_access(baseviewer, subviewer, indices):
     tensorlib, _ = get_backend()
 
     index_selection = []
