@@ -50,7 +50,7 @@ def validate(spec, schema_name, version=None):
         )
         return validator.validate(spec)
     except jsonschema.ValidationError as err:
-        raise InvalidSpecification(err)
+        raise InvalidSpecification(err, schema_name)
 
 
 def options_from_eqdelimstring(opts):
@@ -91,11 +91,11 @@ def digest(obj, algorithm='sha256'):
         ValueError: If the object is not JSON-serializable or if the algorithm is not supported.
 
     Args:
-        obj (`obj`): A JSON-serializable object to compute the digest of. Usually a :class:`~pyhf.workspace.Workspace` object.
-        algorithm (`str`): The hashing algorithm to use.
+        obj (:obj:`jsonable`): A JSON-serializable object to compute the digest of. Usually a :class:`~pyhf.workspace.Workspace` object.
+        algorithm (:obj:`str`): The hashing algorithm to use.
 
     Returns:
-        digest (`str`): The digest for the JSON-serialized object provided and hash algorithm specified.
+        digest (:obj:`str`): The digest for the JSON-serialized object provided and hash algorithm specified.
     """
 
     try:
@@ -111,3 +111,26 @@ def digest(obj, algorithm='sha256'):
             f"{algorithm} is not an algorithm provided by Python's hashlib library."
         )
     return hash_alg(stringified).hexdigest()
+
+
+def remove_prefix(text, prefix):
+    """
+    Remove a prefix from the beginning of the provided text.
+
+    Example:
+
+        >>> import pyhf
+        >>> pyhf.utils.remove_prefix("alpha_syst1", "alpha_")
+        'syst1'
+
+    Args:
+        text (:obj:`str`): A provided input to manipulate.
+        prefix (:obj:`str`): A prefix to remove from provided input, if it exists.
+
+    Returns:
+        stripped_text (:obj:`str`): Text with the prefix removed.
+    """
+    # NB: python3.9 can be `return text.removeprefix(prefix)`
+    if text.startswith(prefix):
+        return text[len(prefix) :]
+    return text
